Function cu29_log_runtime::log_debug_mode
source · pub fn log_debug_mode(
entry: &mut CuLogEntry,
format_str: &str,
param_names: &[&str],
) -> CuResult<()>Expand description
This version of log is only compiled in debug mode This allows a normal logging framework to be bridged.